@@ -34,12 +34,13 @@ from pyworkflow.tests import BaseTest, setupTestProject
 from tomo.tests import DataSet
 from tomo.protocols import (ProtImportCoordinates3D,
                             ProtImportTomograms,
-                            ProtImportSubTomograms, ProtImportTs)
+                            ProtImportSubTomograms,
+                            ProtImportTs)
+
 
 from xmipptomo.protocols import XmippProtSubtomoProject, XmippProtConnectedComponents, XmippProtApplyTransformSubtomo, \
-    XmippProtSubtomoMapBack, XmippProtPhantomSubtomo, XmippProtScoreCoordinates, \
-    XmippProtHalfMapsSubtomo, XmippProtPhantomTomo, XmippProtSubtractionSubtomo, XmippProtFitEllipsoid, XmippProtCCroi, \
-    XmippProtSplitTiltSeries
+    XmippProtSubtomoMapBack, XmippProtPhantomSubtomo, XmippProtScoreCoordinates, XmippProtScoreTransform, \
+    XmippProtHalfMapsSubtomo, XmippProtPhantomTomo, XmippProtSubtractionSubtomo, XmippProtCCroi, XmippProtFitEllipsoid, XmippProtSplitTiltSeries
 
 from xmipptomo.protocols.protocol_phantom_tomo import OutputPhantomTomos
 from xmipptomo.protocols.protocol_project_top import SubtomoProjectOutput
@@ -99,8 +100,8 @@ class TestXmipptomoProtProjectZ(BaseTest):
     def _runPreviousProtocols(cls):
         if cls.importProt is None:
             protImport = cls.newProtocol(ProtImportSubTomograms,
-                                      filesPath=cls.setOfSubtomograms,
-                                      samplingRate=5)
+                                         filesPath=cls.setOfSubtomograms,
+                                         samplingRate=5)
             cls.launchProtocol(protImport)
             cls.importProt = protImport
         return cls.importProt
@@ -111,7 +112,7 @@ class TestXmipptomoProtProjectZ(BaseTest):
                                 input=protImport.outputSubTomograms)
         self.launchProtocol(proj)
         output = getattr(proj, SubtomoProjectOutput.particles.name)
-        self.assertSetSize(output, 4,"There was a problem with particles output")
+        self.assertSetSize(output, 4, "There was a problem with particles output")
         return proj
 
     def _createProjY(self):
@@ -122,7 +123,7 @@ class TestXmipptomoProtProjectZ(BaseTest):
         self.launchProtocol(proj)
 
         output = getattr(proj, SubtomoProjectOutput.particles.name)
-        self.assertSetSize(output, 4,"There was a problem with particles output")
+        self.assertSetSize(output, 4, "There was a problem with particles output")
         return proj
 
     def _createProjZ_range(self):
@@ -133,7 +134,7 @@ class TestXmipptomoProtProjectZ(BaseTest):
                                 cropParam=20)
         self.launchProtocol(proj)
         output = getattr(proj, SubtomoProjectOutput.particles.name)
-        self.assertSetSize(output,4, "There was a problem with particles output")
+        self.assertSetSize(output, 4, "There was a problem with particles output")
         return proj
 
     def _createRadAvgZ(self):
@@ -143,7 +144,7 @@ class TestXmipptomoProtProjectZ(BaseTest):
                                 radAvg=True)
         self.launchProtocol(proj)
         output = getattr(proj, SubtomoProjectOutput.particles.name)
-        self.assertSetSize(output,4, "There was a problem with particles output")
+        self.assertSetSize(output, 4, "There was a problem with particles output")
         return proj
 
     def test_top(self):
@@ -233,8 +234,9 @@ class TestXmipptomoMapback(BaseTest):
         mapback.inputRef.setExtended("outputSubtomograms.1")
         self.launchProtocol(mapback)
 
-        self.assertSetSize(getattr(mapback,XmippProtSubtomoMapBack._possibleOutputs.tomograms.name), 1,
-                             "There was a problem with tomograms output")
+        self.assertSetSize(getattr(mapback, XmippProtSubtomoMapBack._possibleOutputs.tomograms.name), 1,
+                           "There was a problem with tomograms output")
+
 
 class TestXmippTomoPhantom(BaseTest):
     """This class check if the protocol create phantom tomograms works properly."""
@@ -243,9 +245,7 @@ class TestXmippTomoPhantom(BaseTest):
     def setUpClass(cls):
         setupTestProject(cls)
 
-
     def test_phantom(self):
-
         phantom = self.newProtocol(XmippProtPhantomTomo,
                                    ntomos=2,
                                    nparticles=10)
@@ -253,7 +253,8 @@ class TestXmippTomoPhantom(BaseTest):
         tomograms = getattr(phantom, OutputPhantomTomos.tomograms.name)
         self.assertSetSize(tomograms, 2, "There was a problem with subtomograms output")
 
-        self.assertIsNotNone(tomograms.getAcquisition().getMagnification(), "Acquisition magnification not populated properly")
+        self.assertIsNotNone(tomograms.getAcquisition().getMagnification(),
+                             "Acquisition magnification not populated properly")
 
         coordinates = getattr(phantom, OutputPhantomTomos.coordinates3D.name)
         self.assertSetSize(coordinates, 20, "There was a problem with subtomograms output")
@@ -272,9 +273,9 @@ class XmippTomoScoreCoordinates(BaseTest):
 
     def _runPreviousProtocols(self):
         protImportTomogram = self.newProtocol(ProtImportTomograms,
-                                      filesPath=self.tomogram,
-                                      samplingRate=2,
-                                      objLabel='Import Tomogram')
+                                              filesPath=self.tomogram,
+                                              samplingRate=2,
+                                              objLabel='Import Tomogram')
         self.launchProtocol(protImportTomogram)
         output = getattr(protImportTomogram, 'outputTomograms', None)
         self.assertIsNotNone(output,
@@ -313,7 +314,6 @@ class XmippTomoScoreCoordinates(BaseTest):
         return getattr(protScoreCoordinates, 'outputCoordinates')
 
     def test_score_coordinates(self):
-
         # Run imports
         protCoords = self._runPreviousProtocols()
 
@@ -421,10 +421,10 @@ class TestXmipptomoSubtractionSubtomo(BaseTest):
         self.assertIsNotNone(createAverage.outputSubtomograms,
                              "There was a problem with subtomogram average phantom output")
         createSubtomos = self.newProtocol(XmippProtPhantomSubtomo,
-                                        option=1,
-                                        nsubtomos=10,
-                                        rotate=True,
-                                        applyShift=True)
+                                          option=1,
+                                          nsubtomos=10,
+                                          rotate=True,
+                                          applyShift=True)
         self.launchProtocol(createSubtomos)
         self.assertIsNotNone(createSubtomos.outputSubtomograms,
                              "There was a problem with subtomogram phantoms output")
